@@ -39,7 +39,7 @@ static char *compatible_version[] = {
     "4.9.6",
     "4.10", "4.10.1", "4.10.2", "4.10.3", "4.10.4",
     "4.10.5", "4.10.6", "4.10.7", "4.10.8", "4.10.9",
-    "4.10.10", "4.11", "4.12", "4.13", "4.14"
+    "4.10.10", "4.11", "4.12", "4.13", "4.14", "4.15"
     PR_VERSION
 };
 
@@ -55,8 +55,8 @@ static char *incompatible_version[] = {
     "3.0", "3.0.1",
     "3.1", "3.1.1", "3.1.2", "3.1.3",
     "3.5", "3.5.1",
-    "4.15.1",
-    "4.16", "4.16.1",
+    "4.16.1",
+    "4.17", "4.17.1",
     "10.0", "11.1", "12.14.20"
 };
 
